<?php
namespace Themes\kbgolf\pro\app\Http\Controllers\Auth;


use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use App\Services\DbUpdateService;
use Illuminate\Support\Facades\Redirect;
use SocialiteProviders\Apple\Provider;
use Laravel\Socialite\Facades\Socialite;
use Laravel\Socialite\Two\GoogleProvider;
use Laravel\Socialite\Two\FacebookProvider;
use SocialiteProviders\Kakao\KakaoProvider;
use App\Providers\Socialite\OAuth2\DaboryProvider;
use SocialiteProviders\Naver\Provider as NaverProvider;

class SocialTalkController extends Controller
{
    private $callApiService;
    private $dbUpdateService;
    private $appleTokenService;
    private $oauth2Info;
    private $target;


    public function __construct(CallApiService $callApiService, DbUpdateService $dbUpdateService)
    {
        $this->callApiService = $callApiService;
        $this->dbUpdateService = $dbUpdateService;
    }

    public function redirectToProvider($provider)
    {
        // dd($provider);
        $this->oauth2Info = request('oauth2Info');
        // dump($this->oauth2Info);
        return $this->setConfig($provider, request('target'))->redirect();
    }

    public function login($provider)
    {
        [$this->target, $ssoBrand] = explode('-', $provider);
        $response = $this->callApiService->callApi([
            'url' => 'setup-page',
            'data' => [
                'PageVars' => [
                    'Query' => "(setup_code = 'sso-client' and brand_code = '{$provider}') and is_on_use = '1'",
                    'Limit' => 100
                ]
            ],
        ]);
        // dd($response);

        $this->oauth2Info = json_decode($response['Page'][0]['SetupJson'], true);
        // $loginRoute = $this->target == 'member' ? 'member-login' : 'user-login';

        try {
            $userSocial = $this->setConfig($ssoBrand, $this->target)->user();
        } catch (Exception $e) {
            return redirect()->route($loginRoute)->with(['mgs' => $e->getMessage()]);
        }

        if ($this->target == 'member') {
            if (strpos($provider, 'naver') !== false) {
                // return redirect()->route('member-signup.index')->with('socialEmail', $user['email']);
                // $redirectUrl = getLoginRedirectUrl($this->oauth2Info['AfterMemberLoginUri']);
                // return redirect()->to($redirectUrl);
                // $naverTalkUrl = 'https://talk.naver.com/ct/w5ubd2'; // 예시 URL, 실제로는 생성된 URL로 대체해야 합니다.
                // // 로그인 완료 후 팝업으로 열기 위한 JavaScript 반환
                // return view('views.layouts.master')->with('naverTalkUrl', $naverTalkUrl);
                return Redirect::away('https://talk.naver.com/ct/w5ubd2');
            }elseif(strpos($provider, 'kakao') !== false){
                // $kakaoChatUrl = 'https://pf.kakao.com/_aAAGj/chat';
                // return view('views.index')->with('kakaoChatUrl', $kakaoChatUrl);
                return Redirect::away('https://pf.kakao.com/_aAAGj/chat');
                // return redirect()->route('member-signup.index')->with('socialEmail', $user['email']);
                // $redirectUrl = getLoginRedirectUrl($this->oauth2Info['AfterMemberLoginUri']);
                // return redirect()->to($redirectUrl);
            }
        }
    }

    public function setConfig($provider, $target)
    {
        // dd($target);
        $config = [
            'client_id' => $this->oauth2Info['ClientId'],
            'client_secret' => $this->oauth2Info['ClientSecret'],
            'redirect' => "/social/$target-$provider/callback"
        ];
        // dd($config);
        switch ($provider) {
            case 'dabory':
                $driver = Socialite::buildProvider(DaboryProvider::class, [
                    'client_id' => config('app.api.main.ClientId'),
                    'client_secret' => config('app.api.main.ClientSecret'),
                    'redirect' => $config['redirect']
                ]);
                break;
            case 'facebook':
                $driver = Socialite::buildProvider(FacebookProvider::class, $config);
                break;
            case 'kakao':
                $driver = Socialite::buildProvider(KakaoProvider::class, $config);
                break;
            case 'google':
                $driver = Socialite::buildProvider(GoogleProvider::class, $config);
                break;
            case 'naver':
                $driver = Socialite::buildProvider(NaverProvider::class, $config);
                break;
            case 'apple':

                $config['client_secret'] = $this->appleTokenService->generate(
                    $this->oauth2Info['PrivateKey'],
                    $this->oauth2Info['ClientId'],
                    $this->oauth2Info['TeamId'],
                    $this->oauth2Info['KeyId'],
                );

                $driver = Socialite::buildProvider(Provider::class, $config);
                break;
        }

        return $driver;
    }
}
